@@ -13,7 +13,7 @@ def fetchFromGithub(repo_url="https://api.github.com/repos/<USER>/<REPO>/content
     if response and response.status_code == 200:
         binary_content = base64.b64decode(response.json()["content"])
         content = binary_content.decode("utf-8")
-        json = json.loads(content)
-        print(json)
+        jsontext = json.loads(content)
+        return jsontext
     else:
         raise Exception("Unable to download "+repo_url+": "+response)
